==> haskell-wai-conduit-3.0.0.4-705.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-conduit
version:              3.0.0.4
visibility:           public
id:                   wai-conduit-3.0.0.4-B7nqBvZxWIaLt3IzcjghUK
key:                  wai-conduit-3.0.0.4-B7nqBvZxWIaLt3IzcjghUK
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.

category:             Web, Conduit
abi:                  970e3aa467186776b701dc357cc559cb
exposed:              True
exposed-modules:      Network.Wai.Conduit
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-conduit-3.0.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-conduit-3.0.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-conduit
hs-libraries:         HSwai-conduit-3.0.0.4-B7nqBvZxWIaLt3IzcjghUK
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS transformers-0.6.1.0
    wai-3.2.4-DrO6v22Rmno6pXUhKStSuj

haddock-interfaces:   /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html:         /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-conduit-3.0.0.4-706-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-conduit
version:              3.0.0.4
visibility:           public
id:                   wai-conduit-3.0.0.4-5k9A8KiBEnMDVxxiIVNGlK
key:                  wai-conduit-3.0.0.4-5k9A8KiBEnMDVxxiIVNGlK
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.

category:             Web, Conduit
abi:                  f760cfcbb09538a15ef61c5349d3eb66
exposed:              True
exposed-modules:      Network.Wai.Conduit
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-conduit-3.0.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-conduit-3.0.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-conduit
hs-libraries:         HSwai-conduit-3.0.0.4-5k9A8KiBEnMDVxxiIVNGlK
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt transformers-0.6.1.0
    wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63

haddock-interfaces:   /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html:         /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
